import { MouseEventHandler, ReactElement } from 'react';
import { type BaseButtonProps } from '@leafygreen-ui/button';
import { DarkModeProps } from '@leafygreen-ui/lib';
import { MenuItemProps, type MenuProps as ImportedMenuProps } from '@leafygreen-ui/menu';
import { InferredPolymorphicProps, PolymorphicAs } from '@leafygreen-ui/polymorphic';
export type MenuItemType = ReactElement<InferredPolymorphicProps<PolymorphicAs, MenuItemProps>>;
export type MenuItemsType = Array<MenuItemType>;
export declare const Variant: {
    readonly Default: "default";
    readonly Primary: "primary";
    readonly Danger: "danger";
};
export type Variant = (typeof Variant)[keyof typeof Variant];
export declare const Align: {
    readonly Top: "top";
    readonly Bottom: "bottom";
};
export type Align = (typeof Align)[keyof typeof Align];
export declare const Justify: {
    readonly Start: "start";
    readonly End: "end";
};
export type Justify = (typeof Justify)[keyof typeof Justify];
type ButtonProps = Omit<BaseButtonProps, 'rightGlyph' | 'variant'>;
export type SelectedMenuProps = Pick<ImportedMenuProps, 'darkMode' | 'maxHeight' | 'adjustOnMutation' | 'popoverZIndex' | 'renderDarkMenu' | 'renderMode' | 'portalClassName' | 'portalContainer' | 'portalRef' | 'scrollContainer' | 'align' | 'justify' | 'id' | 'open' | 'setOpen'>;
export interface MenuProps extends SelectedMenuProps {
    /**
     * Determines the alignment of the menu relative to the component wrapper.
     *
     * @default 'bottom'
     */
    align?: Align;
    /**
     * Determines the justification of the menu relative to the component wrapper.
     *
     *  @default 'end'
     */
    justify?: Justify;
    /**
     * The menu items to appear in the menu dropdown. Must be an array of `<MenuItem />`.
     *
     * ```js
     * [
     *   <MenuItem key='0' onClick={()=>{}}> Menu Item</MenuItem>,
     *   <MenuItem key='1' description="I am a description" disabled>Disabled Menu Item</MenuItem>,
     *   <MenuItem key='2' description="I am also a description">,
     *     Menu Item With Description
     *   </MenuItem>
     * ]
     * ```
     *
     * @type Array<MenuItem>
     */
    menuItems: MenuItemsType;
    /**
     * Callback fired when the trigger is clicked.
     */
    onTriggerClick?: MouseEventHandler;
    /**
     * aria-label for the menu trigger button.
     */
    triggerAriaLabel?: string;
    /**
     * Callback fired when a menuItem is clicked.
     */
    onChange?: MouseEventHandler;
}
export interface InternalSplitButtonProps extends DarkModeProps, ButtonProps, MenuProps {
    /**
     * Sets the variant for both Buttons.
     *
     * @default 'default'
     */
    variant?: Variant;
    /**
     * The text that will appear inside of the primary button.
     */
    label: string;
    /**
     * A test id put onto the root element.
     */
    'data-testid'?: string;
}
export type SplitButtonProps<TAsProp extends PolymorphicAs = 'button'> = InferredPolymorphicProps<TAsProp, InternalSplitButtonProps>;
export {};
//# sourceMappingURL=SplitButton.types.d.ts.map